@@ -161,7 +161,7 @@ impl UiConfig {
     }
 }
 
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+#[derive(Debug, Clone, Default, Serialize, Deserialize, PartialEq)]
 #[serde(deny_unknown_fields)]
 pub struct UiElement {
     #[serde(default)]
@@ -445,6 +445,9 @@ pub struct GeneralConfig {
     #[serde(default)]
     pub read_only: bool,
 
+    #[serde(default)]
+    pub enable_recover_mode: bool,
+
     #[serde(default)]
     pub cursor: UiElement,
 
@@ -466,6 +469,9 @@ pub struct GeneralConfig {
     #[serde(default)]
     pub selection_ui: UiConfig,
 
+    #[serde(default)]
+    pub focus_selection_ui: UiConfig,
+
     #[serde(default)]
     pub sort_and_filter_ui: SortAndFilterUi,
 
@@ -480,6 +486,9 @@ pub struct GeneralConfig {
 
     #[serde(default)]
     pub initial_layout: Option<String>,
+
+    #[serde(default)]
+    pub start_fifo: Option<String>,
 }
 
 impl GeneralConfig {
@@ -557,6 +566,26 @@ impl GeneralConfig {
     pub fn enable_mouse(&self) -> bool {
         self.enable_mouse
     }
+
+    /// Get a reference to the general config's enable recover mode.
+    pub fn enable_recover_mode(&self) -> bool {
+        self.enable_recover_mode
+    }
+
+    /// Set the general config's read only.
+    pub fn set_read_only(&mut self, read_only: bool) {
+        self.read_only = read_only;
+    }
+
+    /// Get a reference to the general config's start fifo.
+    pub fn start_fifo(&self) -> Option<&String> {
+        self.start_fifo.as_ref()
+    }
+
+    /// Get a reference to the general config's focus selection ui.
+    pub fn focus_selection_ui(&self) -> &UiConfig {
+        &self.focus_selection_ui
+    }
 }
 
 #[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
@@ -638,6 +667,9 @@ pub struct Mode {
 
     #[serde(default)]
     pub key_bindings: KeyBindings,
+
+    #[serde(default)]
+    pub layout: Option<Layout>,
 }
 
 impl Mode {
@@ -760,6 +792,11 @@ impl Mode {
     pub fn key_bindings(&self) -> &KeyBindings {
         &self.key_bindings
     }
+
+    /// Get a reference to the mode's layout.
+    pub fn layout(&self) -> &Option<Layout> {
+        &self.layout
+    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -815,6 +852,9 @@ pub struct BuiltinModesConfig {
 
     #[serde(default)]
     pub switch_layout: Mode,
+
+    #[serde(default)]
+    pub quit: Mode,
 }
 
 impl BuiltinModesConfig {
@@ -844,6 +884,7 @@ impl BuiltinModesConfig {
             "relative path does not contain" => Some(&self.relative_path_does_not_contain),
             "switch layout" => Some(&self.switch_layout),
             "switch_layout" => Some(&self.switch_layout),
+            "quit" => Some(&self.quit),
             _ => None,
         }
     }
@@ -932,6 +973,11 @@ impl BuiltinModesConfig {
     pub fn recover(&self) -> &Mode {
         &self.recover
     }
+
+    /// Get a reference to the builtin modes config's quit.
+    pub fn quit(&self) -> &Mode {
+        &self.quit
+    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -968,7 +1014,7 @@ impl ModesConfig {
     }
 }
 
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+#[derive(Debug, Clone, Default, Serialize, Deserialize, PartialEq)]
 #[serde(deny_unknown_fields)]
 pub struct PanelUiConfig {
     #[serde(default)]
