@@ -8,7 +8,7 @@ use serde::Deserialize;
 use std::fs;
 
 const DEFAULT_LUA_SCRIPT: &str = include_str!("init.lua");
-const UPGRADE_GUIDE_LINK: &str = "https://github.com/sayanarijit/xplr/wiki/Upgrade-Guide";
+const UPGRADE_GUIDE_LINK: &str = "https://xplr.dev/en/upgrade-guide.html";
 
 fn parse_version(version: &str) -> Result<(u16, u16, u16, Option<u16>)> {
     let mut configv = version.split('.');
@@ -63,7 +63,7 @@ fn resolve_fn_recursive<'lua, 'a>(
 /// This function resolves paths like `builtin.func_foo`, `custom.func_bar` into lua functions.
 pub fn resolve_fn<'lua>(globals: &mlua::Table<'lua>, path: &str) -> Result<mlua::Function<'lua>> {
     let path = format!("xplr.fn.{}", path);
-    resolve_fn_recursive(&globals, path.split('.'))
+    resolve_fn_recursive(globals, path.split('.'))
 }
 
 /// Used to initialize Lua globals
@@ -133,23 +133,30 @@ mod test {
         assert!(check_version(VERSION, "foo path").is_ok());
 
         // Current release if OK
-        assert!(check_version("0.14.3", "foo path").is_ok());
+        assert!(check_version("0.15.0", "foo path").is_ok());
 
         // Prev major release is ERR
+        // - Not yet
 
         // Prev minor release is ERR (Change when we get to v1)
-        assert!(check_version("0.13.3", "foo path").is_err());
+        assert!(check_version("0.14.0", "foo path").is_err());
 
         // Prev bugfix release is OK
-        assert!(check_version("0.14.2", "foo path").is_ok());
+        // assert!(check_version("0.15.-1", "foo path").is_ok());
 
         // Next major release is ERR
-        assert!(check_version("1.14.3", "foo path").is_err());
+        assert!(check_version("1.15.0", "foo path").is_err());
 
         // Next minor release is ERR
-        assert!(check_version("0.15.3", "foo path").is_err());
+        assert!(check_version("0.16.7", "foo path").is_err());
 
         // Next bugfix release is ERR (Change when we get to v1)
-        assert!(check_version("0.14.4", "foo path").is_err());
+        assert!(check_version("0.15.8", "foo path").is_err());
+    }
+
+    #[test]
+    fn test_upgrade_guide_has_latest_version() {
+        let guide = include_str!("../docs/en/src/upgrade-guide.md");
+        assert!(guide.contains(VERSION));
     }
 }
